"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ProductTypeLevelEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ProductTypeLevel(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ProductTypeLevel.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ProductTypeLevelEnum.ProductTypeLevel.V(0)
        UNKNOWN = ProductTypeLevelEnum.ProductTypeLevel.V(1)
        LEVEL1 = ProductTypeLevelEnum.ProductTypeLevel.V(7)
        LEVEL2 = ProductTypeLevelEnum.ProductTypeLevel.V(8)
        LEVEL3 = ProductTypeLevelEnum.ProductTypeLevel.V(9)
        LEVEL4 = ProductTypeLevelEnum.ProductTypeLevel.V(10)
        LEVEL5 = ProductTypeLevelEnum.ProductTypeLevel.V(11)
    class ProductTypeLevel(metaclass=_ProductTypeLevel):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ProductTypeLevelEnum.ProductTypeLevel.V(0)
    UNKNOWN = ProductTypeLevelEnum.ProductTypeLevel.V(1)
    LEVEL1 = ProductTypeLevelEnum.ProductTypeLevel.V(7)
    LEVEL2 = ProductTypeLevelEnum.ProductTypeLevel.V(8)
    LEVEL3 = ProductTypeLevelEnum.ProductTypeLevel.V(9)
    LEVEL4 = ProductTypeLevelEnum.ProductTypeLevel.V(10)
    LEVEL5 = ProductTypeLevelEnum.ProductTypeLevel.V(11)
    def __init__(
        self,
    ) -> None: ...

global___ProductTypeLevelEnum = ProductTypeLevelEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import typing

from .google_ads_service_pb2 import *

class GoogleAdsServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def Search(
        self,
        request: global___SearchGoogleAdsRequest,
    ) -> global___SearchGoogleAdsResponse: ...
    def SearchStream(
        self,
        request: global___SearchGoogleAdsStreamRequest,
    ) -> typing.Iterator[global___SearchGoogleAdsStreamResponse]: ...
    def Mutate(
        self,
        request: global___MutateGoogleAdsRequest,
    ) -> global___MutateGoogleAdsResponse: ...

class GoogleAdsServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Search(
        self,
        request: global___SearchGoogleAdsRequest,
        context: grpc.ServicerContext,
    ) -> global___SearchGoogleAdsResponse: ...
    @abc.abstractmethod
    def SearchStream(
        self,
        request: global___SearchGoogleAdsStreamRequest,
        context: grpc.ServicerContext,
    ) -> typing.Iterator[global___SearchGoogleAdsStreamResponse]: ...
    @abc.abstractmethod
    def Mutate(
        self,
        request: global___MutateGoogleAdsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateGoogleAdsResponse: ...

def add_GoogleAdsServiceServicer_to_server(
    servicer: GoogleAdsServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.google_ads_field_category_pb2
import google.ads.google_ads.v4.proto.enums.google_ads_field_data_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GoogleAdsField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    SELECTABLE_FIELD_NUMBER: builtins.int
    FILTERABLE_FIELD_NUMBER: builtins.int
    SORTABLE_FIELD_NUMBER: builtins.int
    SELECTABLE_WITH_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RESOURCES_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    SEGMENTS_FIELD_NUMBER: builtins.int
    ENUM_VALUES_FIELD_NUMBER: builtins.int
    DATA_TYPE_FIELD_NUMBER: builtins.int
    TYPE_URL_FIELD_NUMBER: builtins.int
    IS_REPEATED_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    category: google.ads.google_ads.v4.proto.enums.google_ads_field_category_pb2.GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategory.V = (
        ...
    )
    data_type: google.ads.google_ads.v4.proto.enums.google_ads_field_data_type_pb2.GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V = (
        ...
    )
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def selectable(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def filterable(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def sortable(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def selectable_with(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def attribute_resources(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def metrics(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def segments(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def enum_values(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def type_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def is_repeated(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        category: google.ads.google_ads.v4.proto.enums.google_ads_field_category_pb2.GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategory.V = ...,
        selectable: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        filterable: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        sortable: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        selectable_with: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        attribute_resources: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        metrics: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        segments: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        enum_values: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        data_type: google.ads.google_ads.v4.proto.enums.google_ads_field_data_type_pb2.GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V = ...,
        type_url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        is_repeated: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "filterable",
            b"filterable",
            "is_repeated",
            b"is_repeated",
            "name",
            b"name",
            "selectable",
            b"selectable",
            "sortable",
            b"sortable",
            "type_url",
            b"type_url",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "attribute_resources",
            b"attribute_resources",
            "category",
            b"category",
            "data_type",
            b"data_type",
            "enum_values",
            b"enum_values",
            "filterable",
            b"filterable",
            "is_repeated",
            b"is_repeated",
            "metrics",
            b"metrics",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "segments",
            b"segments",
            "selectable",
            b"selectable",
            "selectable_with",
            b"selectable_with",
            "sortable",
            b"sortable",
            "type_url",
            b"type_url",
        ],
    ) -> None: ...

global___GoogleAdsField = GoogleAdsField



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AssetLinkErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AssetLinkError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AssetLinkError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AssetLinkErrorEnum.AssetLinkError.V(0)
        UNKNOWN = AssetLinkErrorEnum.AssetLinkError.V(1)
        PINNING_UNSUPPORTED = AssetLinkErrorEnum.AssetLinkError.V(2)
        UNSUPPORTED_FIELD_TYPE = AssetLinkErrorEnum.AssetLinkError.V(3)
        FIELD_TYPE_INCOMPATIBLE_WITH_ASSET_TYPE = AssetLinkErrorEnum.AssetLinkError.V(4)
        FIELD_TYPE_INCOMPATIBLE_WITH_CAMPAIGN_TYPE = (
            AssetLinkErrorEnum.AssetLinkError.V(5)
        )
        INCOMPATIBLE_ADVERTISING_CHANNEL_TYPE = AssetLinkErrorEnum.AssetLinkError.V(6)
        IMAGE_NOT_WITHIN_SPECIFIED_DIMENSION_RANGE = (
            AssetLinkErrorEnum.AssetLinkError.V(7)
        )
        INVALID_PINNED_FIELD = AssetLinkErrorEnum.AssetLinkError.V(8)
        MEDIA_BUNDLE_ASSET_FILE_SIZE_TOO_LARGE = AssetLinkErrorEnum.AssetLinkError.V(9)
        NOT_ENOUGH_AVAILABLE_ASSET_LINKS_FOR_VALID_COMBINATION = (
            AssetLinkErrorEnum.AssetLinkError.V(10)
        )
        NOT_ENOUGH_AVAILABLE_ASSET_LINKS_WITH_FALLBACK = (
            AssetLinkErrorEnum.AssetLinkError.V(11)
        )
        NOT_ENOUGH_AVAILABLE_ASSET_LINKS_WITH_FALLBACK_FOR_VALID_COMBINATION = (
            AssetLinkErrorEnum.AssetLinkError.V(12)
        )
        YOUTUBE_VIDEO_REMOVED = AssetLinkErrorEnum.AssetLinkError.V(13)
        YOUTUBE_VIDEO_TOO_LONG = AssetLinkErrorEnum.AssetLinkError.V(14)
        YOUTUBE_VIDEO_TOO_SHORT = AssetLinkErrorEnum.AssetLinkError.V(15)
    class AssetLinkError(metaclass=_AssetLinkError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AssetLinkErrorEnum.AssetLinkError.V(0)
    UNKNOWN = AssetLinkErrorEnum.AssetLinkError.V(1)
    PINNING_UNSUPPORTED = AssetLinkErrorEnum.AssetLinkError.V(2)
    UNSUPPORTED_FIELD_TYPE = AssetLinkErrorEnum.AssetLinkError.V(3)
    FIELD_TYPE_INCOMPATIBLE_WITH_ASSET_TYPE = AssetLinkErrorEnum.AssetLinkError.V(4)
    FIELD_TYPE_INCOMPATIBLE_WITH_CAMPAIGN_TYPE = AssetLinkErrorEnum.AssetLinkError.V(5)
    INCOMPATIBLE_ADVERTISING_CHANNEL_TYPE = AssetLinkErrorEnum.AssetLinkError.V(6)
    IMAGE_NOT_WITHIN_SPECIFIED_DIMENSION_RANGE = AssetLinkErrorEnum.AssetLinkError.V(7)
    INVALID_PINNED_FIELD = AssetLinkErrorEnum.AssetLinkError.V(8)
    MEDIA_BUNDLE_ASSET_FILE_SIZE_TOO_LARGE = AssetLinkErrorEnum.AssetLinkError.V(9)
    NOT_ENOUGH_AVAILABLE_ASSET_LINKS_FOR_VALID_COMBINATION = (
        AssetLinkErrorEnum.AssetLinkError.V(10)
    )
    NOT_ENOUGH_AVAILABLE_ASSET_LINKS_WITH_FALLBACK = (
        AssetLinkErrorEnum.AssetLinkError.V(11)
    )
    NOT_ENOUGH_AVAILABLE_ASSET_LINKS_WITH_FALLBACK_FOR_VALID_COMBINATION = (
        AssetLinkErrorEnum.AssetLinkError.V(12)
    )
    YOUTUBE_VIDEO_REMOVED = AssetLinkErrorEnum.AssetLinkError.V(13)
    YOUTUBE_VIDEO_TOO_LONG = AssetLinkErrorEnum.AssetLinkError.V(14)
    YOUTUBE_VIDEO_TOO_SHORT = AssetLinkErrorEnum.AssetLinkError.V(15)
    def __init__(
        self,
    ) -> None: ...

global___AssetLinkErrorEnum = AssetLinkErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.mime_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class YoutubeVideoAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    YOUTUBE_VIDEO_ID_FIELD_NUMBER: builtins.int
    youtube_video_id: typing.Text = ...
    def __init__(
        self,
        *,
        youtube_video_id: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_youtube_video_id",
            b"_youtube_video_id",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_youtube_video_id",
            b"_youtube_video_id",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_youtube_video_id", b"_youtube_video_id"
        ],
    ) -> typing_extensions.Literal["youtube_video_id"]: ...

global___YoutubeVideoAsset = YoutubeVideoAsset

class MediaBundleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["_data", b"_data", "data", b"data"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["_data", b"_data", "data", b"data"]
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_data", b"_data"]
    ) -> typing_extensions.Literal["data"]: ...

global___MediaBundleAsset = MediaBundleAsset

class ImageAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    FULL_SIZE_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    file_size: builtins.int = ...
    mime_type: google.ads.google_ads.v5.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = (
        ...
    )
    @property
    def full_size(self) -> global___ImageDimension: ...
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
        file_size: builtins.int = ...,
        mime_type: google.ads.google_ads.v5.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = ...,
        full_size: typing.Optional[global___ImageDimension] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_data",
            b"_data",
            "_file_size",
            b"_file_size",
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_data",
            b"_data",
            "_file_size",
            b"_file_size",
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
            "mime_type",
            b"mime_type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_data", b"_data"]
    ) -> typing_extensions.Literal["data"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_file_size", b"_file_size"]
    ) -> typing_extensions.Literal["file_size"]: ...

global___ImageAsset = ImageAsset

class ImageDimension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_PIXELS_FIELD_NUMBER: builtins.int
    WIDTH_PIXELS_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    height_pixels: builtins.int = ...
    width_pixels: builtins.int = ...
    url: typing.Text = ...
    def __init__(
        self,
        *,
        height_pixels: builtins.int = ...,
        width_pixels: builtins.int = ...,
        url: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_height_pixels",
            b"_height_pixels",
            "_url",
            b"_url",
            "_width_pixels",
            b"_width_pixels",
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_height_pixels",
            b"_height_pixels",
            "_url",
            b"_url",
            "_width_pixels",
            b"_width_pixels",
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_height_pixels", b"_height_pixels"],
    ) -> typing_extensions.Literal["height_pixels"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_url", b"_url"]
    ) -> typing_extensions.Literal["url"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_width_pixels", b"_width_pixels"]
    ) -> typing_extensions.Literal["width_pixels"]: ...

global___ImageDimension = ImageDimension

class TextAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    def __init__(
        self,
        *,
        text: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["_text", b"_text", "text", b"text"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["_text", b"_text", "text", b"text"]
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_text", b"_text"]
    ) -> typing_extensions.Literal["text"]: ...

global___TextAsset = TextAsset

class BookOnGoogleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___BookOnGoogleAsset = BookOnGoogleAsset



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SettingErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _SettingError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SettingError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = SettingErrorEnum.SettingError.V(0)
        UNKNOWN = SettingErrorEnum.SettingError.V(1)
        SETTING_TYPE_IS_NOT_AVAILABLE = SettingErrorEnum.SettingError.V(3)
        SETTING_TYPE_IS_NOT_COMPATIBLE_WITH_CAMPAIGN = SettingErrorEnum.SettingError.V(
            4
        )
        TARGETING_SETTING_CONTAINS_INVALID_CRITERION_TYPE_GROUP = (
            SettingErrorEnum.SettingError.V(5)
        )
        TARGETING_SETTING_DEMOGRAPHIC_CRITERION_TYPE_GROUPS_MUST_BE_SET_TO_TARGET_ALL = SettingErrorEnum.SettingError.V(
            6
        )
        TARGETING_SETTING_CANNOT_CHANGE_TARGET_ALL_TO_FALSE_FOR_DEMOGRAPHIC_CRITERION_TYPE_GROUP = SettingErrorEnum.SettingError.V(
            7
        )
        DYNAMIC_SEARCH_ADS_SETTING_AT_LEAST_ONE_FEED_ID_MUST_BE_PRESENT = (
            SettingErrorEnum.SettingError.V(8)
        )
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_DOMAIN_NAME = (
            SettingErrorEnum.SettingError.V(9)
        )
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_SUBDOMAIN_NAME = (
            SettingErrorEnum.SettingError.V(10)
        )
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_LANGUAGE_CODE = (
            SettingErrorEnum.SettingError.V(11)
        )
        TARGET_ALL_IS_NOT_ALLOWED_FOR_PLACEMENT_IN_SEARCH_CAMPAIGN = (
            SettingErrorEnum.SettingError.V(12)
        )
        SETTING_VALUE_NOT_COMPATIBLE_WITH_CAMPAIGN = SettingErrorEnum.SettingError.V(20)
    class SettingError(metaclass=_SettingError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = SettingErrorEnum.SettingError.V(0)
    UNKNOWN = SettingErrorEnum.SettingError.V(1)
    SETTING_TYPE_IS_NOT_AVAILABLE = SettingErrorEnum.SettingError.V(3)
    SETTING_TYPE_IS_NOT_COMPATIBLE_WITH_CAMPAIGN = SettingErrorEnum.SettingError.V(4)
    TARGETING_SETTING_CONTAINS_INVALID_CRITERION_TYPE_GROUP = (
        SettingErrorEnum.SettingError.V(5)
    )
    TARGETING_SETTING_DEMOGRAPHIC_CRITERION_TYPE_GROUPS_MUST_BE_SET_TO_TARGET_ALL = (
        SettingErrorEnum.SettingError.V(6)
    )
    TARGETING_SETTING_CANNOT_CHANGE_TARGET_ALL_TO_FALSE_FOR_DEMOGRAPHIC_CRITERION_TYPE_GROUP = SettingErrorEnum.SettingError.V(
        7
    )
    DYNAMIC_SEARCH_ADS_SETTING_AT_LEAST_ONE_FEED_ID_MUST_BE_PRESENT = (
        SettingErrorEnum.SettingError.V(8)
    )
    DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_DOMAIN_NAME = (
        SettingErrorEnum.SettingError.V(9)
    )
    DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_SUBDOMAIN_NAME = (
        SettingErrorEnum.SettingError.V(10)
    )
    DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_LANGUAGE_CODE = (
        SettingErrorEnum.SettingError.V(11)
    )
    TARGET_ALL_IS_NOT_ALLOWED_FOR_PLACEMENT_IN_SEARCH_CAMPAIGN = (
        SettingErrorEnum.SettingError.V(12)
    )
    SETTING_VALUE_NOT_COMPATIBLE_WITH_CAMPAIGN = SettingErrorEnum.SettingError.V(20)
    def __init__(
        self,
    ) -> None: ...

global___SettingErrorEnum = SettingErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.geo_target_constant_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GeoTargetConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    TARGET_TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CANONICAL_NAME_FIELD_NUMBER: builtins.int
    PARENT_GEO_TARGET_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    name: typing.Text = ...
    country_code: typing.Text = ...
    target_type: typing.Text = ...
    status: google.ads.google_ads.v5.proto.enums.geo_target_constant_status_pb2.GeoTargetConstantStatusEnum.GeoTargetConstantStatus.V = (
        ...
    )
    canonical_name: typing.Text = ...
    parent_geo_target: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        name: typing.Text = ...,
        country_code: typing.Text = ...,
        target_type: typing.Text = ...,
        status: google.ads.google_ads.v5.proto.enums.geo_target_constant_status_pb2.GeoTargetConstantStatusEnum.GeoTargetConstantStatus.V = ...,
        canonical_name: typing.Text = ...,
        parent_geo_target: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_canonical_name",
            b"_canonical_name",
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_parent_geo_target",
            b"_parent_geo_target",
            "_target_type",
            b"_target_type",
            "canonical_name",
            b"canonical_name",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "name",
            b"name",
            "parent_geo_target",
            b"parent_geo_target",
            "target_type",
            b"target_type",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_canonical_name",
            b"_canonical_name",
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_parent_geo_target",
            b"_parent_geo_target",
            "_target_type",
            b"_target_type",
            "canonical_name",
            b"canonical_name",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "name",
            b"name",
            "parent_geo_target",
            b"parent_geo_target",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "target_type",
            b"target_type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_canonical_name", b"_canonical_name"],
    ) -> typing_extensions.Literal["canonical_name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_country_code", b"_country_code"]
    ) -> typing_extensions.Literal["country_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_parent_geo_target", b"_parent_geo_target"
        ],
    ) -> typing_extensions.Literal["parent_geo_target"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_target_type", b"_target_type"]
    ) -> typing_extensions.Literal["target_type"]: ...

global___GeoTargetConstant = GeoTargetConstant



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.billing_setup_pb2
import grpc

from .billing_setup_service_pb2 import *

class BillingSetupServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetBillingSetup(
        self,
        request: global___GetBillingSetupRequest,
    ) -> google.ads.google_ads.v5.proto.resources.billing_setup_pb2.BillingSetup: ...
    def MutateBillingSetup(
        self,
        request: global___MutateBillingSetupRequest,
    ) -> global___MutateBillingSetupResponse: ...

class BillingSetupServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetBillingSetup(
        self,
        request: global___GetBillingSetupRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.billing_setup_pb2.BillingSetup: ...
    @abc.abstractmethod
    def MutateBillingSetup(
        self,
        request: global___MutateBillingSetupRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateBillingSetupResponse: ...

def add_BillingSetupServiceServicer_to_server(
    servicer: BillingSetupServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.distance_view_pb2
import grpc

from .distance_view_service_pb2 import *

class DistanceViewServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetDistanceView(
        self,
        request: global___GetDistanceViewRequest,
    ) -> google.ads.google_ads.v4.proto.resources.distance_view_pb2.DistanceView: ...

class DistanceViewServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetDistanceView(
        self,
        request: global___GetDistanceViewRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.distance_view_pb2.DistanceView: ...

def add_DistanceViewServiceServicer_to_server(
    servicer: DistanceViewServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CriterionCategoryLocaleAvailabilityModeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CriterionCategoryLocaleAvailabilityMode(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CriterionCategoryLocaleAvailabilityMode.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
            0
        )
        UNKNOWN = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
            1
        )
        ALL_LOCALES = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
            2
        )
        COUNTRY_AND_ALL_LANGUAGES = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
            3
        )
        LANGUAGE_AND_ALL_COUNTRIES = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
            4
        )
        COUNTRY_AND_LANGUAGE = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
            5
        )
    class CriterionCategoryLocaleAvailabilityMode(
        metaclass=_CriterionCategoryLocaleAvailabilityMode
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
        0
    )
    UNKNOWN = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
        1
    )
    ALL_LOCALES = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
        2
    )
    COUNTRY_AND_ALL_LANGUAGES = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
        3
    )
    LANGUAGE_AND_ALL_COUNTRIES = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
        4
    )
    COUNTRY_AND_LANGUAGE = CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V(
        5
    )
    def __init__(
        self,
    ) -> None: ...

global___CriterionCategoryLocaleAvailabilityModeEnum = (
    CriterionCategoryLocaleAvailabilityModeEnum
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.campaign_draft_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignDraft(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    DRAFT_ID_FIELD_NUMBER: builtins.int
    BASE_CAMPAIGN_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DRAFT_CAMPAIGN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    HAS_EXPERIMENT_RUNNING_FIELD_NUMBER: builtins.int
    LONG_RUNNING_OPERATION_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    draft_id: builtins.int = ...
    base_campaign: typing.Text = ...
    name: typing.Text = ...
    draft_campaign: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.campaign_draft_status_pb2.CampaignDraftStatusEnum.CampaignDraftStatus.V = (
        ...
    )
    has_experiment_running: builtins.bool = ...
    long_running_operation: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        draft_id: builtins.int = ...,
        base_campaign: typing.Text = ...,
        name: typing.Text = ...,
        draft_campaign: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.campaign_draft_status_pb2.CampaignDraftStatusEnum.CampaignDraftStatus.V = ...,
        has_experiment_running: builtins.bool = ...,
        long_running_operation: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_base_campaign",
            b"_base_campaign",
            "_draft_campaign",
            b"_draft_campaign",
            "_draft_id",
            b"_draft_id",
            "_has_experiment_running",
            b"_has_experiment_running",
            "_long_running_operation",
            b"_long_running_operation",
            "_name",
            b"_name",
            "base_campaign",
            b"base_campaign",
            "draft_campaign",
            b"draft_campaign",
            "draft_id",
            b"draft_id",
            "has_experiment_running",
            b"has_experiment_running",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_base_campaign",
            b"_base_campaign",
            "_draft_campaign",
            b"_draft_campaign",
            "_draft_id",
            b"_draft_id",
            "_has_experiment_running",
            b"_has_experiment_running",
            "_long_running_operation",
            b"_long_running_operation",
            "_name",
            b"_name",
            "base_campaign",
            b"base_campaign",
            "draft_campaign",
            b"draft_campaign",
            "draft_id",
            b"draft_id",
            "has_experiment_running",
            b"has_experiment_running",
            "long_running_operation",
            b"long_running_operation",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_base_campaign", b"_base_campaign"],
    ) -> typing_extensions.Literal["base_campaign"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_draft_campaign", b"_draft_campaign"],
    ) -> typing_extensions.Literal["draft_campaign"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_draft_id", b"_draft_id"]
    ) -> typing_extensions.Literal["draft_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_has_experiment_running", b"_has_experiment_running"
        ],
    ) -> typing_extensions.Literal["has_experiment_running"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_long_running_operation", b"_long_running_operation"
        ],
    ) -> typing_extensions.Literal["long_running_operation"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...

global___CampaignDraft = CampaignDraft



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedAttributeReferenceErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedAttributeReferenceError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedAttributeReferenceError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V(0)
        UNKNOWN = FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V(1)
        CANNOT_REFERENCE_REMOVED_FEED = (
            FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V(2)
        )
        INVALID_FEED_NAME = (
            FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V(3)
        )
        INVALID_FEED_ATTRIBUTE_NAME = (
            FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V(4)
        )
    class FeedAttributeReferenceError(metaclass=_FeedAttributeReferenceError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V(0)
    UNKNOWN = FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V(1)
    CANNOT_REFERENCE_REMOVED_FEED = (
        FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V(2)
    )
    INVALID_FEED_NAME = FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V(3)
    INVALID_FEED_ATTRIBUTE_NAME = (
        FeedAttributeReferenceErrorEnum.FeedAttributeReferenceError.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___FeedAttributeReferenceErrorEnum = FeedAttributeReferenceErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.google_ads_field_category_pb2
import google.ads.google_ads.v5.proto.enums.google_ads_field_data_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GoogleAdsField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    SELECTABLE_FIELD_NUMBER: builtins.int
    FILTERABLE_FIELD_NUMBER: builtins.int
    SORTABLE_FIELD_NUMBER: builtins.int
    SELECTABLE_WITH_FIELD_NUMBER: builtins.int
    ATTRIBUTE_RESOURCES_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    SEGMENTS_FIELD_NUMBER: builtins.int
    ENUM_VALUES_FIELD_NUMBER: builtins.int
    DATA_TYPE_FIELD_NUMBER: builtins.int
    TYPE_URL_FIELD_NUMBER: builtins.int
    IS_REPEATED_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    name: typing.Text = ...
    category: google.ads.google_ads.v5.proto.enums.google_ads_field_category_pb2.GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategory.V = (
        ...
    )
    selectable: builtins.bool = ...
    filterable: builtins.bool = ...
    sortable: builtins.bool = ...
    selectable_with: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    attribute_resources: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    metrics: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    segments: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    enum_values: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    data_type: google.ads.google_ads.v5.proto.enums.google_ads_field_data_type_pb2.GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V = (
        ...
    )
    type_url: typing.Text = ...
    is_repeated: builtins.bool = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        name: typing.Text = ...,
        category: google.ads.google_ads.v5.proto.enums.google_ads_field_category_pb2.GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategory.V = ...,
        selectable: builtins.bool = ...,
        filterable: builtins.bool = ...,
        sortable: builtins.bool = ...,
        selectable_with: typing.Optional[typing.Iterable[typing.Text]] = ...,
        attribute_resources: typing.Optional[typing.Iterable[typing.Text]] = ...,
        metrics: typing.Optional[typing.Iterable[typing.Text]] = ...,
        segments: typing.Optional[typing.Iterable[typing.Text]] = ...,
        enum_values: typing.Optional[typing.Iterable[typing.Text]] = ...,
        data_type: google.ads.google_ads.v5.proto.enums.google_ads_field_data_type_pb2.GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V = ...,
        type_url: typing.Text = ...,
        is_repeated: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_filterable",
            b"_filterable",
            "_is_repeated",
            b"_is_repeated",
            "_name",
            b"_name",
            "_selectable",
            b"_selectable",
            "_sortable",
            b"_sortable",
            "_type_url",
            b"_type_url",
            "filterable",
            b"filterable",
            "is_repeated",
            b"is_repeated",
            "name",
            b"name",
            "selectable",
            b"selectable",
            "sortable",
            b"sortable",
            "type_url",
            b"type_url",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_filterable",
            b"_filterable",
            "_is_repeated",
            b"_is_repeated",
            "_name",
            b"_name",
            "_selectable",
            b"_selectable",
            "_sortable",
            b"_sortable",
            "_type_url",
            b"_type_url",
            "attribute_resources",
            b"attribute_resources",
            "category",
            b"category",
            "data_type",
            b"data_type",
            "enum_values",
            b"enum_values",
            "filterable",
            b"filterable",
            "is_repeated",
            b"is_repeated",
            "metrics",
            b"metrics",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "segments",
            b"segments",
            "selectable",
            b"selectable",
            "selectable_with",
            b"selectable_with",
            "sortable",
            b"sortable",
            "type_url",
            b"type_url",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_filterable", b"_filterable"]
    ) -> typing_extensions.Literal["filterable"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_is_repeated", b"_is_repeated"]
    ) -> typing_extensions.Literal["is_repeated"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_selectable", b"_selectable"]
    ) -> typing_extensions.Literal["selectable"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_sortable", b"_sortable"]
    ) -> typing_extensions.Literal["sortable"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_type_url", b"_type_url"]
    ) -> typing_extensions.Literal["type_url"]: ...

global___GoogleAdsField = GoogleAdsField



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.search_term_targeting_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SearchTermView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    SEARCH_TERM_FIELD_NUMBER: builtins.int
    AD_GROUP_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    search_term: typing.Text = ...
    ad_group: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.search_term_targeting_status_pb2.SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        search_term: typing.Text = ...,
        ad_group: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.search_term_targeting_status_pb2.SearchTermTargetingStatusEnum.SearchTermTargetingStatus.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group",
            b"_ad_group",
            "_search_term",
            b"_search_term",
            "ad_group",
            b"ad_group",
            "search_term",
            b"search_term",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group",
            b"_ad_group",
            "_search_term",
            b"_search_term",
            "ad_group",
            b"ad_group",
            "resource_name",
            b"resource_name",
            "search_term",
            b"search_term",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ad_group", b"_ad_group"]
    ) -> typing_extensions.Literal["ad_group"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_search_term", b"_search_term"]
    ) -> typing_extensions.Literal["search_term"]: ...

global___SearchTermView = SearchTermView



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.conversion_adjustment_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.rpc.status_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UploadConversionAdjustmentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    CONVERSION_ADJUSTMENTS_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_FIELD_NUMBER: builtins.int
    VALIDATE_ONLY_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    partial_failure: builtins.bool = ...
    validate_only: builtins.bool = ...
    @property
    def conversion_adjustments(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ConversionAdjustment
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        conversion_adjustments: typing.Optional[
            typing.Iterable[global___ConversionAdjustment]
        ] = ...,
        partial_failure: builtins.bool = ...,
        validate_only: builtins.bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "conversion_adjustments",
            b"conversion_adjustments",
            "customer_id",
            b"customer_id",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

global___UploadConversionAdjustmentsRequest = UploadConversionAdjustmentsRequest

class UploadConversionAdjustmentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARTIAL_FAILURE_ERROR_FIELD_NUMBER: builtins.int
    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def partial_failure_error(self) -> google.rpc.status_pb2.Status: ...
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ConversionAdjustmentResult
    ]: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing.Optional[google.rpc.status_pb2.Status] = ...,
        results: typing.Optional[
            typing.Iterable[global___ConversionAdjustmentResult]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

global___UploadConversionAdjustmentsResponse = UploadConversionAdjustmentsResponse

class ConversionAdjustment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    ADJUSTMENT_DATE_TIME_FIELD_NUMBER: builtins.int
    ADJUSTMENT_TYPE_FIELD_NUMBER: builtins.int
    RESTATEMENT_VALUE_FIELD_NUMBER: builtins.int
    GCLID_DATE_TIME_PAIR_FIELD_NUMBER: builtins.int
    ORDER_ID_FIELD_NUMBER: builtins.int
    conversion_action: typing.Text = ...
    adjustment_date_time: typing.Text = ...
    adjustment_type: google.ads.google_ads.v5.proto.enums.conversion_adjustment_type_pb2.ConversionAdjustmentTypeEnum.ConversionAdjustmentType.V = (
        ...
    )
    order_id: typing.Text = ...
    @property
    def restatement_value(self) -> global___RestatementValue: ...
    @property
    def gclid_date_time_pair(self) -> global___GclidDateTimePair: ...
    def __init__(
        self,
        *,
        conversion_action: typing.Text = ...,
        adjustment_date_time: typing.Text = ...,
        adjustment_type: google.ads.google_ads.v5.proto.enums.conversion_adjustment_type_pb2.ConversionAdjustmentTypeEnum.ConversionAdjustmentType.V = ...,
        restatement_value: typing.Optional[global___RestatementValue] = ...,
        gclid_date_time_pair: typing.Optional[global___GclidDateTimePair] = ...,
        order_id: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_adjustment_date_time",
            b"_adjustment_date_time",
            "_conversion_action",
            b"_conversion_action",
            "adjustment_date_time",
            b"adjustment_date_time",
            "conversion_action",
            b"conversion_action",
            "conversion_identifier",
            b"conversion_identifier",
            "gclid_date_time_pair",
            b"gclid_date_time_pair",
            "order_id",
            b"order_id",
            "restatement_value",
            b"restatement_value",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_adjustment_date_time",
            b"_adjustment_date_time",
            "_conversion_action",
            b"_conversion_action",
            "adjustment_date_time",
            b"adjustment_date_time",
            "adjustment_type",
            b"adjustment_type",
            "conversion_action",
            b"conversion_action",
            "conversion_identifier",
            b"conversion_identifier",
            "gclid_date_time_pair",
            b"gclid_date_time_pair",
            "order_id",
            b"order_id",
            "restatement_value",
            b"restatement_value",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_adjustment_date_time", b"_adjustment_date_time"
        ],
    ) -> typing_extensions.Literal["adjustment_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions.Literal["conversion_action"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "conversion_identifier", b"conversion_identifier"
        ],
    ) -> typing_extensions.Literal["gclid_date_time_pair", "order_id"]: ...

global___ConversionAdjustment = ConversionAdjustment

class RestatementValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADJUSTED_VALUE_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    adjusted_value: builtins.float = ...
    currency_code: typing.Text = ...
    def __init__(
        self,
        *,
        adjusted_value: builtins.float = ...,
        currency_code: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_adjusted_value",
            b"_adjusted_value",
            "_currency_code",
            b"_currency_code",
            "adjusted_value",
            b"adjusted_value",
            "currency_code",
            b"currency_code",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_adjusted_value",
            b"_adjusted_value",
            "_currency_code",
            b"_currency_code",
            "adjusted_value",
            b"adjusted_value",
            "currency_code",
            b"currency_code",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_adjusted_value", b"_adjusted_value"],
    ) -> typing_extensions.Literal["adjusted_value"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions.Literal["currency_code"]: ...

global___RestatementValue = RestatementValue

class GclidDateTimePair(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GCLID_FIELD_NUMBER: builtins.int
    CONVERSION_DATE_TIME_FIELD_NUMBER: builtins.int
    gclid: typing.Text = ...
    conversion_date_time: typing.Text = ...
    def __init__(
        self,
        *,
        gclid: typing.Text = ...,
        conversion_date_time: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_date_time",
            b"_conversion_date_time",
            "_gclid",
            b"_gclid",
            "conversion_date_time",
            b"conversion_date_time",
            "gclid",
            b"gclid",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_date_time",
            b"_conversion_date_time",
            "_gclid",
            b"_gclid",
            "conversion_date_time",
            b"conversion_date_time",
            "gclid",
            b"gclid",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_date_time", b"_conversion_date_time"
        ],
    ) -> typing_extensions.Literal["conversion_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_gclid", b"_gclid"]
    ) -> typing_extensions.Literal["gclid"]: ...

global___GclidDateTimePair = GclidDateTimePair

class ConversionAdjustmentResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    ADJUSTMENT_DATE_TIME_FIELD_NUMBER: builtins.int
    ADJUSTMENT_TYPE_FIELD_NUMBER: builtins.int
    GCLID_DATE_TIME_PAIR_FIELD_NUMBER: builtins.int
    ORDER_ID_FIELD_NUMBER: builtins.int
    conversion_action: typing.Text = ...
    adjustment_date_time: typing.Text = ...
    adjustment_type: google.ads.google_ads.v5.proto.enums.conversion_adjustment_type_pb2.ConversionAdjustmentTypeEnum.ConversionAdjustmentType.V = (
        ...
    )
    order_id: typing.Text = ...
    @property
    def gclid_date_time_pair(self) -> global___GclidDateTimePair: ...
    def __init__(
        self,
        *,
        conversion_action: typing.Text = ...,
        adjustment_date_time: typing.Text = ...,
        adjustment_type: google.ads.google_ads.v5.proto.enums.conversion_adjustment_type_pb2.ConversionAdjustmentTypeEnum.ConversionAdjustmentType.V = ...,
        gclid_date_time_pair: typing.Optional[global___GclidDateTimePair] = ...,
        order_id: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_adjustment_date_time",
            b"_adjustment_date_time",
            "_conversion_action",
            b"_conversion_action",
            "adjustment_date_time",
            b"adjustment_date_time",
            "conversion_action",
            b"conversion_action",
            "conversion_identifier",
            b"conversion_identifier",
            "gclid_date_time_pair",
            b"gclid_date_time_pair",
            "order_id",
            b"order_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_adjustment_date_time",
            b"_adjustment_date_time",
            "_conversion_action",
            b"_conversion_action",
            "adjustment_date_time",
            b"adjustment_date_time",
            "adjustment_type",
            b"adjustment_type",
            "conversion_action",
            b"conversion_action",
            "conversion_identifier",
            b"conversion_identifier",
            "gclid_date_time_pair",
            b"gclid_date_time_pair",
            "order_id",
            b"order_id",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_adjustment_date_time", b"_adjustment_date_time"
        ],
    ) -> typing_extensions.Literal["adjustment_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions.Literal["conversion_action"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "conversion_identifier", b"conversion_identifier"
        ],
    ) -> typing_extensions.Literal["gclid_date_time_pair", "order_id"]: ...

global___ConversionAdjustmentResult = ConversionAdjustmentResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.extension_feed_item_pb2
import grpc

from .extension_feed_item_service_pb2 import *

class ExtensionFeedItemServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetExtensionFeedItem(
        self,
        request: global___GetExtensionFeedItemRequest,
    ) -> google.ads.google_ads.v5.proto.resources.extension_feed_item_pb2.ExtensionFeedItem: ...
    def MutateExtensionFeedItems(
        self,
        request: global___MutateExtensionFeedItemsRequest,
    ) -> global___MutateExtensionFeedItemsResponse: ...

class ExtensionFeedItemServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetExtensionFeedItem(
        self,
        request: global___GetExtensionFeedItemRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.extension_feed_item_pb2.ExtensionFeedItem: ...
    @abc.abstractmethod
    def MutateExtensionFeedItems(
        self,
        request: global___MutateExtensionFeedItemsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateExtensionFeedItemsResponse: ...

def add_ExtensionFeedItemServiceServicer_to_server(
    servicer: ExtensionFeedItemServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PositiveGeoTargetTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PositiveGeoTargetType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PositiveGeoTargetType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(0)
        UNKNOWN = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(1)
        PRESENCE_OR_INTEREST = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(5)
        SEARCH_INTEREST = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(6)
        PRESENCE = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(7)
    class PositiveGeoTargetType(metaclass=_PositiveGeoTargetType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(0)
    UNKNOWN = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(1)
    PRESENCE_OR_INTEREST = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(5)
    SEARCH_INTEREST = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(6)
    PRESENCE = PositiveGeoTargetTypeEnum.PositiveGeoTargetType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___PositiveGeoTargetTypeEnum = PositiveGeoTargetTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ExtensionSettingErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ExtensionSettingError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ExtensionSettingError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ExtensionSettingErrorEnum.ExtensionSettingError.V(0)
        UNKNOWN = ExtensionSettingErrorEnum.ExtensionSettingError.V(1)
        EXTENSIONS_REQUIRED = ExtensionSettingErrorEnum.ExtensionSettingError.V(2)
        FEED_TYPE_EXTENSION_TYPE_MISMATCH = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(3)
        )
        INVALID_FEED_TYPE = ExtensionSettingErrorEnum.ExtensionSettingError.V(4)
        INVALID_FEED_TYPE_FOR_CUSTOMER_EXTENSION_SETTING = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(5)
        )
        CANNOT_CHANGE_FEED_ITEM_ON_CREATE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(6)
        )
        CANNOT_UPDATE_NEWLY_CREATED_EXTENSION = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(7)
        )
        NO_EXISTING_AD_GROUP_EXTENSION_SETTING_FOR_TYPE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(8)
        )
        NO_EXISTING_CAMPAIGN_EXTENSION_SETTING_FOR_TYPE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(9)
        )
        NO_EXISTING_CUSTOMER_EXTENSION_SETTING_FOR_TYPE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(10)
        )
        AD_GROUP_EXTENSION_SETTING_ALREADY_EXISTS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(11)
        )
        CAMPAIGN_EXTENSION_SETTING_ALREADY_EXISTS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(12)
        )
        CUSTOMER_EXTENSION_SETTING_ALREADY_EXISTS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(13)
        )
        AD_GROUP_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(14)
        )
        CAMPAIGN_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(15)
        )
        CUSTOMER_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(16)
        )
        VALUE_OUT_OF_RANGE = ExtensionSettingErrorEnum.ExtensionSettingError.V(17)
        CANNOT_SET_FIELD_WITH_FINAL_URLS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(18)
        )
        FINAL_URLS_NOT_SET = ExtensionSettingErrorEnum.ExtensionSettingError.V(19)
        INVALID_PHONE_NUMBER = ExtensionSettingErrorEnum.ExtensionSettingError.V(20)
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(21)
        )
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(22)
        )
        PREMIUM_RATE_NUMBER_NOT_ALLOWED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(23)
        )
        DISALLOWED_NUMBER_TYPE = ExtensionSettingErrorEnum.ExtensionSettingError.V(24)
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(25)
        )
        VANITY_PHONE_NUMBER_NOT_ALLOWED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(26)
        )
        INVALID_COUNTRY_CODE = ExtensionSettingErrorEnum.ExtensionSettingError.V(27)
        INVALID_CALL_CONVERSION_TYPE_ID = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(28)
        )
        CUSTOMER_NOT_IN_ALLOWLIST_FOR_CALLTRACKING = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(69)
        )
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(30)
        )
        INVALID_APP_ID = ExtensionSettingErrorEnum.ExtensionSettingError.V(31)
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(32)
        )
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(33)
        )
        REVIEW_EXTENSION_SOURCE_NOT_ELIGIBLE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(34)
        )
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(35)
        )
        MISSING_FIELD = ExtensionSettingErrorEnum.ExtensionSettingError.V(36)
        INCONSISTENT_CURRENCY_CODES = ExtensionSettingErrorEnum.ExtensionSettingError.V(
            37
        )
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(38)
        )
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(39)
        )
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(40)
        )
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(41)
        )
        UNSUPPORTED_VALUE = ExtensionSettingErrorEnum.ExtensionSettingError.V(42)
        INVALID_DEVICE_PREFERENCE = ExtensionSettingErrorEnum.ExtensionSettingError.V(
            43
        )
        INVALID_SCHEDULE_END = ExtensionSettingErrorEnum.ExtensionSettingError.V(45)
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(47)
        )
        OVERLAPPING_SCHEDULES_NOT_ALLOWED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(48)
        )
        SCHEDULE_END_NOT_AFTER_START = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(49)
        )
        TOO_MANY_SCHEDULES_PER_DAY = ExtensionSettingErrorEnum.ExtensionSettingError.V(
            50
        )
        DUPLICATE_EXTENSION_FEED_ITEM_EDIT = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(51)
        )
        INVALID_SNIPPETS_HEADER = ExtensionSettingErrorEnum.ExtensionSettingError.V(52)
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(53)
        )
        CAMPAIGN_TARGETING_MISMATCH = ExtensionSettingErrorEnum.ExtensionSettingError.V(
            54
        )
        CANNOT_OPERATE_ON_REMOVED_FEED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(55)
        )
        EXTENSION_TYPE_REQUIRED = ExtensionSettingErrorEnum.ExtensionSettingError.V(56)
        INCOMPATIBLE_UNDERLYING_MATCHING_FUNCTION = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(57)
        )
        START_DATE_AFTER_END_DATE = ExtensionSettingErrorEnum.ExtensionSettingError.V(
            58
        )
        INVALID_PRICE_FORMAT = ExtensionSettingErrorEnum.ExtensionSettingError.V(59)
        PROMOTION_INVALID_TIME = ExtensionSettingErrorEnum.ExtensionSettingError.V(60)
        PROMOTION_CANNOT_SET_PERCENT_DISCOUNT_AND_MONEY_DISCOUNT = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(61)
        )
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(62)
        )
        TOO_MANY_DECIMAL_PLACES_SPECIFIED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(63)
        )
        INVALID_LANGUAGE_CODE = ExtensionSettingErrorEnum.ExtensionSettingError.V(64)
        UNSUPPORTED_LANGUAGE = ExtensionSettingErrorEnum.ExtensionSettingError.V(65)
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(66)
        )
        EXTENSION_SETTING_UPDATE_IS_A_NOOP = (
            ExtensionSettingErrorEnum.ExtensionSettingError.V(67)
        )
        DISALLOWED_TEXT = ExtensionSettingErrorEnum.ExtensionSettingError.V(68)
    class ExtensionSettingError(metaclass=_ExtensionSettingError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ExtensionSettingErrorEnum.ExtensionSettingError.V(0)
    UNKNOWN = ExtensionSettingErrorEnum.ExtensionSettingError.V(1)
    EXTENSIONS_REQUIRED = ExtensionSettingErrorEnum.ExtensionSettingError.V(2)
    FEED_TYPE_EXTENSION_TYPE_MISMATCH = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(3)
    )
    INVALID_FEED_TYPE = ExtensionSettingErrorEnum.ExtensionSettingError.V(4)
    INVALID_FEED_TYPE_FOR_CUSTOMER_EXTENSION_SETTING = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(5)
    )
    CANNOT_CHANGE_FEED_ITEM_ON_CREATE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(6)
    )
    CANNOT_UPDATE_NEWLY_CREATED_EXTENSION = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(7)
    )
    NO_EXISTING_AD_GROUP_EXTENSION_SETTING_FOR_TYPE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(8)
    )
    NO_EXISTING_CAMPAIGN_EXTENSION_SETTING_FOR_TYPE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(9)
    )
    NO_EXISTING_CUSTOMER_EXTENSION_SETTING_FOR_TYPE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(10)
    )
    AD_GROUP_EXTENSION_SETTING_ALREADY_EXISTS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(11)
    )
    CAMPAIGN_EXTENSION_SETTING_ALREADY_EXISTS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(12)
    )
    CUSTOMER_EXTENSION_SETTING_ALREADY_EXISTS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(13)
    )
    AD_GROUP_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(14)
    )
    CAMPAIGN_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(15)
    )
    CUSTOMER_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(16)
    )
    VALUE_OUT_OF_RANGE = ExtensionSettingErrorEnum.ExtensionSettingError.V(17)
    CANNOT_SET_FIELD_WITH_FINAL_URLS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(18)
    )
    FINAL_URLS_NOT_SET = ExtensionSettingErrorEnum.ExtensionSettingError.V(19)
    INVALID_PHONE_NUMBER = ExtensionSettingErrorEnum.ExtensionSettingError.V(20)
    PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(21)
    )
    CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(22)
    )
    PREMIUM_RATE_NUMBER_NOT_ALLOWED = ExtensionSettingErrorEnum.ExtensionSettingError.V(
        23
    )
    DISALLOWED_NUMBER_TYPE = ExtensionSettingErrorEnum.ExtensionSettingError.V(24)
    INVALID_DOMESTIC_PHONE_NUMBER_FORMAT = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(25)
    )
    VANITY_PHONE_NUMBER_NOT_ALLOWED = ExtensionSettingErrorEnum.ExtensionSettingError.V(
        26
    )
    INVALID_COUNTRY_CODE = ExtensionSettingErrorEnum.ExtensionSettingError.V(27)
    INVALID_CALL_CONVERSION_TYPE_ID = ExtensionSettingErrorEnum.ExtensionSettingError.V(
        28
    )
    CUSTOMER_NOT_IN_ALLOWLIST_FOR_CALLTRACKING = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(69)
    )
    CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(30)
    )
    INVALID_APP_ID = ExtensionSettingErrorEnum.ExtensionSettingError.V(31)
    QUOTES_IN_REVIEW_EXTENSION_SNIPPET = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(32)
    )
    HYPHENS_IN_REVIEW_EXTENSION_SNIPPET = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(33)
    )
    REVIEW_EXTENSION_SOURCE_NOT_ELIGIBLE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(34)
    )
    SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(35)
    )
    MISSING_FIELD = ExtensionSettingErrorEnum.ExtensionSettingError.V(36)
    INCONSISTENT_CURRENCY_CODES = ExtensionSettingErrorEnum.ExtensionSettingError.V(37)
    PRICE_EXTENSION_HAS_DUPLICATED_HEADERS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(38)
    )
    PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(39)
    )
    PRICE_EXTENSION_HAS_TOO_FEW_ITEMS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(40)
    )
    PRICE_EXTENSION_HAS_TOO_MANY_ITEMS = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(41)
    )
    UNSUPPORTED_VALUE = ExtensionSettingErrorEnum.ExtensionSettingError.V(42)
    INVALID_DEVICE_PREFERENCE = ExtensionSettingErrorEnum.ExtensionSettingError.V(43)
    INVALID_SCHEDULE_END = ExtensionSettingErrorEnum.ExtensionSettingError.V(45)
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(47)
    )
    OVERLAPPING_SCHEDULES_NOT_ALLOWED = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(48)
    )
    SCHEDULE_END_NOT_AFTER_START = ExtensionSettingErrorEnum.ExtensionSettingError.V(49)
    TOO_MANY_SCHEDULES_PER_DAY = ExtensionSettingErrorEnum.ExtensionSettingError.V(50)
    DUPLICATE_EXTENSION_FEED_ITEM_EDIT = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(51)
    )
    INVALID_SNIPPETS_HEADER = ExtensionSettingErrorEnum.ExtensionSettingError.V(52)
    PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(53)
    )
    CAMPAIGN_TARGETING_MISMATCH = ExtensionSettingErrorEnum.ExtensionSettingError.V(54)
    CANNOT_OPERATE_ON_REMOVED_FEED = ExtensionSettingErrorEnum.ExtensionSettingError.V(
        55
    )
    EXTENSION_TYPE_REQUIRED = ExtensionSettingErrorEnum.ExtensionSettingError.V(56)
    INCOMPATIBLE_UNDERLYING_MATCHING_FUNCTION = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(57)
    )
    START_DATE_AFTER_END_DATE = ExtensionSettingErrorEnum.ExtensionSettingError.V(58)
    INVALID_PRICE_FORMAT = ExtensionSettingErrorEnum.ExtensionSettingError.V(59)
    PROMOTION_INVALID_TIME = ExtensionSettingErrorEnum.ExtensionSettingError.V(60)
    PROMOTION_CANNOT_SET_PERCENT_DISCOUNT_AND_MONEY_DISCOUNT = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(61)
    )
    PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(62)
    )
    TOO_MANY_DECIMAL_PLACES_SPECIFIED = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(63)
    )
    INVALID_LANGUAGE_CODE = ExtensionSettingErrorEnum.ExtensionSettingError.V(64)
    UNSUPPORTED_LANGUAGE = ExtensionSettingErrorEnum.ExtensionSettingError.V(65)
    CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(66)
    )
    EXTENSION_SETTING_UPDATE_IS_A_NOOP = (
        ExtensionSettingErrorEnum.ExtensionSettingError.V(67)
    )
    DISALLOWED_TEXT = ExtensionSettingErrorEnum.ExtensionSettingError.V(68)
    def __init__(
        self,
    ) -> None: ...

global___ExtensionSettingErrorEnum = ExtensionSettingErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DistanceBucketEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DistanceBucket(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DistanceBucket.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DistanceBucketEnum.DistanceBucket.V(0)
        UNKNOWN = DistanceBucketEnum.DistanceBucket.V(1)
        WITHIN_700M = DistanceBucketEnum.DistanceBucket.V(2)
        WITHIN_1KM = DistanceBucketEnum.DistanceBucket.V(3)
        WITHIN_5KM = DistanceBucketEnum.DistanceBucket.V(4)
        WITHIN_10KM = DistanceBucketEnum.DistanceBucket.V(5)
        WITHIN_15KM = DistanceBucketEnum.DistanceBucket.V(6)
        WITHIN_20KM = DistanceBucketEnum.DistanceBucket.V(7)
        WITHIN_25KM = DistanceBucketEnum.DistanceBucket.V(8)
        WITHIN_30KM = DistanceBucketEnum.DistanceBucket.V(9)
        WITHIN_35KM = DistanceBucketEnum.DistanceBucket.V(10)
        WITHIN_40KM = DistanceBucketEnum.DistanceBucket.V(11)
        WITHIN_45KM = DistanceBucketEnum.DistanceBucket.V(12)
        WITHIN_50KM = DistanceBucketEnum.DistanceBucket.V(13)
        WITHIN_55KM = DistanceBucketEnum.DistanceBucket.V(14)
        WITHIN_60KM = DistanceBucketEnum.DistanceBucket.V(15)
        WITHIN_65KM = DistanceBucketEnum.DistanceBucket.V(16)
        BEYOND_65KM = DistanceBucketEnum.DistanceBucket.V(17)
        WITHIN_0_7MILES = DistanceBucketEnum.DistanceBucket.V(18)
        WITHIN_1MILE = DistanceBucketEnum.DistanceBucket.V(19)
        WITHIN_5MILES = DistanceBucketEnum.DistanceBucket.V(20)
        WITHIN_10MILES = DistanceBucketEnum.DistanceBucket.V(21)
        WITHIN_15MILES = DistanceBucketEnum.DistanceBucket.V(22)
        WITHIN_20MILES = DistanceBucketEnum.DistanceBucket.V(23)
        WITHIN_25MILES = DistanceBucketEnum.DistanceBucket.V(24)
        WITHIN_30MILES = DistanceBucketEnum.DistanceBucket.V(25)
        WITHIN_35MILES = DistanceBucketEnum.DistanceBucket.V(26)
        WITHIN_40MILES = DistanceBucketEnum.DistanceBucket.V(27)
        BEYOND_40MILES = DistanceBucketEnum.DistanceBucket.V(28)
    class DistanceBucket(metaclass=_DistanceBucket):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DistanceBucketEnum.DistanceBucket.V(0)
    UNKNOWN = DistanceBucketEnum.DistanceBucket.V(1)
    WITHIN_700M = DistanceBucketEnum.DistanceBucket.V(2)
    WITHIN_1KM = DistanceBucketEnum.DistanceBucket.V(3)
    WITHIN_5KM = DistanceBucketEnum.DistanceBucket.V(4)
    WITHIN_10KM = DistanceBucketEnum.DistanceBucket.V(5)
    WITHIN_15KM = DistanceBucketEnum.DistanceBucket.V(6)
    WITHIN_20KM = DistanceBucketEnum.DistanceBucket.V(7)
    WITHIN_25KM = DistanceBucketEnum.DistanceBucket.V(8)
    WITHIN_30KM = DistanceBucketEnum.DistanceBucket.V(9)
    WITHIN_35KM = DistanceBucketEnum.DistanceBucket.V(10)
    WITHIN_40KM = DistanceBucketEnum.DistanceBucket.V(11)
    WITHIN_45KM = DistanceBucketEnum.DistanceBucket.V(12)
    WITHIN_50KM = DistanceBucketEnum.DistanceBucket.V(13)
    WITHIN_55KM = DistanceBucketEnum.DistanceBucket.V(14)
    WITHIN_60KM = DistanceBucketEnum.DistanceBucket.V(15)
    WITHIN_65KM = DistanceBucketEnum.DistanceBucket.V(16)
    BEYOND_65KM = DistanceBucketEnum.DistanceBucket.V(17)
    WITHIN_0_7MILES = DistanceBucketEnum.DistanceBucket.V(18)
    WITHIN_1MILE = DistanceBucketEnum.DistanceBucket.V(19)
    WITHIN_5MILES = DistanceBucketEnum.DistanceBucket.V(20)
    WITHIN_10MILES = DistanceBucketEnum.DistanceBucket.V(21)
    WITHIN_15MILES = DistanceBucketEnum.DistanceBucket.V(22)
    WITHIN_20MILES = DistanceBucketEnum.DistanceBucket.V(23)
    WITHIN_25MILES = DistanceBucketEnum.DistanceBucket.V(24)
    WITHIN_30MILES = DistanceBucketEnum.DistanceBucket.V(25)
    WITHIN_35MILES = DistanceBucketEnum.DistanceBucket.V(26)
    WITHIN_40MILES = DistanceBucketEnum.DistanceBucket.V(27)
    BEYOND_40MILES = DistanceBucketEnum.DistanceBucket.V(28)
    def __init__(
        self,
    ) -> None: ...

global___DistanceBucketEnum = DistanceBucketEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.account_budget_proposal_status_pb2
import google.ads.google_ads.v6.proto.enums.account_budget_proposal_type_pb2
import google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2
import google.ads.google_ads.v6.proto.enums.time_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccountBudgetProposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    BILLING_SETUP_FIELD_NUMBER: builtins.int
    ACCOUNT_BUDGET_FIELD_NUMBER: builtins.int
    PROPOSAL_TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PROPOSED_NAME_FIELD_NUMBER: builtins.int
    APPROVED_START_DATE_TIME_FIELD_NUMBER: builtins.int
    PROPOSED_PURCHASE_ORDER_NUMBER_FIELD_NUMBER: builtins.int
    PROPOSED_NOTES_FIELD_NUMBER: builtins.int
    CREATION_DATE_TIME_FIELD_NUMBER: builtins.int
    APPROVAL_DATE_TIME_FIELD_NUMBER: builtins.int
    PROPOSED_START_DATE_TIME_FIELD_NUMBER: builtins.int
    PROPOSED_START_TIME_TYPE_FIELD_NUMBER: builtins.int
    PROPOSED_END_DATE_TIME_FIELD_NUMBER: builtins.int
    PROPOSED_END_TIME_TYPE_FIELD_NUMBER: builtins.int
    APPROVED_END_DATE_TIME_FIELD_NUMBER: builtins.int
    APPROVED_END_TIME_TYPE_FIELD_NUMBER: builtins.int
    PROPOSED_SPENDING_LIMIT_MICROS_FIELD_NUMBER: builtins.int
    PROPOSED_SPENDING_LIMIT_TYPE_FIELD_NUMBER: builtins.int
    APPROVED_SPENDING_LIMIT_MICROS_FIELD_NUMBER: builtins.int
    APPROVED_SPENDING_LIMIT_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    billing_setup: typing.Text = ...
    account_budget: typing.Text = ...
    proposal_type: google.ads.google_ads.v6.proto.enums.account_budget_proposal_type_pb2.AccountBudgetProposalTypeEnum.AccountBudgetProposalType.V = (
        ...
    )
    status: google.ads.google_ads.v6.proto.enums.account_budget_proposal_status_pb2.AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V = (
        ...
    )
    proposed_name: typing.Text = ...
    approved_start_date_time: typing.Text = ...
    proposed_purchase_order_number: typing.Text = ...
    proposed_notes: typing.Text = ...
    creation_date_time: typing.Text = ...
    approval_date_time: typing.Text = ...
    proposed_start_date_time: typing.Text = ...
    proposed_start_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
        ...
    )
    proposed_end_date_time: typing.Text = ...
    proposed_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
        ...
    )
    approved_end_date_time: typing.Text = ...
    approved_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
        ...
    )
    proposed_spending_limit_micros: builtins.int = ...
    proposed_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = (
        ...
    )
    approved_spending_limit_micros: builtins.int = ...
    approved_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        billing_setup: typing.Text = ...,
        account_budget: typing.Text = ...,
        proposal_type: google.ads.google_ads.v6.proto.enums.account_budget_proposal_type_pb2.AccountBudgetProposalTypeEnum.AccountBudgetProposalType.V = ...,
        status: google.ads.google_ads.v6.proto.enums.account_budget_proposal_status_pb2.AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus.V = ...,
        proposed_name: typing.Text = ...,
        approved_start_date_time: typing.Text = ...,
        proposed_purchase_order_number: typing.Text = ...,
        proposed_notes: typing.Text = ...,
        creation_date_time: typing.Text = ...,
        approval_date_time: typing.Text = ...,
        proposed_start_date_time: typing.Text = ...,
        proposed_start_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
        proposed_end_date_time: typing.Text = ...,
        proposed_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
        approved_end_date_time: typing.Text = ...,
        approved_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
        proposed_spending_limit_micros: builtins.int = ...,
        proposed_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = ...,
        approved_spending_limit_micros: builtins.int = ...,
        approved_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_account_budget",
            b"_account_budget",
            "_approval_date_time",
            b"_approval_date_time",
            "_approved_start_date_time",
            b"_approved_start_date_time",
            "_billing_setup",
            b"_billing_setup",
            "_creation_date_time",
            b"_creation_date_time",
            "_id",
            b"_id",
            "_proposed_name",
            b"_proposed_name",
            "_proposed_notes",
            b"_proposed_notes",
            "_proposed_purchase_order_number",
            b"_proposed_purchase_order_number",
            "account_budget",
            b"account_budget",
            "approval_date_time",
            b"approval_date_time",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "creation_date_time",
            b"creation_date_time",
            "id",
            b"id",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_name",
            b"proposed_name",
            "proposed_notes",
            b"proposed_notes",
            "proposed_purchase_order_number",
            b"proposed_purchase_order_number",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "proposed_start_time",
            b"proposed_start_time",
            "proposed_start_time_type",
            b"proposed_start_time_type",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_account_budget",
            b"_account_budget",
            "_approval_date_time",
            b"_approval_date_time",
            "_approved_start_date_time",
            b"_approved_start_date_time",
            "_billing_setup",
            b"_billing_setup",
            "_creation_date_time",
            b"_creation_date_time",
            "_id",
            b"_id",
            "_proposed_name",
            b"_proposed_name",
            "_proposed_notes",
            b"_proposed_notes",
            "_proposed_purchase_order_number",
            b"_proposed_purchase_order_number",
            "account_budget",
            b"account_budget",
            "approval_date_time",
            b"approval_date_time",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "creation_date_time",
            b"creation_date_time",
            "id",
            b"id",
            "proposal_type",
            b"proposal_type",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_name",
            b"proposed_name",
            "proposed_notes",
            b"proposed_notes",
            "proposed_purchase_order_number",
            b"proposed_purchase_order_number",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "proposed_start_time",
            b"proposed_start_time",
            "proposed_start_time_type",
            b"proposed_start_time_type",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_account_budget", b"_account_budget"],
    ) -> typing_extensions.Literal["account_budget"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_approval_date_time", b"_approval_date_time"
        ],
    ) -> typing_extensions.Literal["approval_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_approved_start_date_time", b"_approved_start_date_time"
        ],
    ) -> typing_extensions.Literal["approved_start_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_billing_setup", b"_billing_setup"],
    ) -> typing_extensions.Literal["billing_setup"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_creation_date_time", b"_creation_date_time"
        ],
    ) -> typing_extensions.Literal["creation_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_proposed_name", b"_proposed_name"],
    ) -> typing_extensions.Literal["proposed_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_proposed_notes", b"_proposed_notes"],
    ) -> typing_extensions.Literal["proposed_notes"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_proposed_purchase_order_number", b"_proposed_purchase_order_number"
        ],
    ) -> typing_extensions.Literal["proposed_purchase_order_number"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "approved_end_time", b"approved_end_time"
        ],
    ) -> typing_extensions.Literal[
        "approved_end_date_time", "approved_end_time_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "approved_spending_limit", b"approved_spending_limit"
        ],
    ) -> typing_extensions.Literal[
        "approved_spending_limit_micros", "approved_spending_limit_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "proposed_end_time", b"proposed_end_time"
        ],
    ) -> typing_extensions.Literal[
        "proposed_end_date_time", "proposed_end_time_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "proposed_spending_limit", b"proposed_spending_limit"
        ],
    ) -> typing_extensions.Literal[
        "proposed_spending_limit_micros", "proposed_spending_limit_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "proposed_start_time", b"proposed_start_time"
        ],
    ) -> typing_extensions.Literal[
        "proposed_start_date_time", "proposed_start_time_type"
    ]: ...

global___AccountBudgetProposal = AccountBudgetProposal



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignExperimentStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignExperimentStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignExperimentStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(0)
        UNKNOWN = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(1)
        INITIALIZING = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(2)
        INITIALIZATION_FAILED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(
            8
        )
        ENABLED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(3)
        GRADUATED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(4)
        REMOVED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(5)
        PROMOTING = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(6)
        PROMOTION_FAILED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(9)
        PROMOTED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(7)
        ENDED_MANUALLY = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(10)
    class CampaignExperimentStatus(metaclass=_CampaignExperimentStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(0)
    UNKNOWN = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(1)
    INITIALIZING = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(2)
    INITIALIZATION_FAILED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(8)
    ENABLED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(3)
    GRADUATED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(4)
    REMOVED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(5)
    PROMOTING = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(6)
    PROMOTION_FAILED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(9)
    PROMOTED = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(7)
    ENDED_MANUALLY = CampaignExperimentStatusEnum.CampaignExperimentStatus.V(10)
    def __init__(
        self,
    ) -> None: ...

global___CampaignExperimentStatusEnum = CampaignExperimentStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AuthenticationErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AuthenticationError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AuthenticationError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AuthenticationErrorEnum.AuthenticationError.V(0)
        UNKNOWN = AuthenticationErrorEnum.AuthenticationError.V(1)
        AUTHENTICATION_ERROR = AuthenticationErrorEnum.AuthenticationError.V(2)
        CLIENT_CUSTOMER_ID_INVALID = AuthenticationErrorEnum.AuthenticationError.V(5)
        CUSTOMER_NOT_FOUND = AuthenticationErrorEnum.AuthenticationError.V(8)
        GOOGLE_ACCOUNT_DELETED = AuthenticationErrorEnum.AuthenticationError.V(9)
        GOOGLE_ACCOUNT_COOKIE_INVALID = AuthenticationErrorEnum.AuthenticationError.V(
            10
        )
        GOOGLE_ACCOUNT_AUTHENTICATION_FAILED = (
            AuthenticationErrorEnum.AuthenticationError.V(25)
        )
        GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH = (
            AuthenticationErrorEnum.AuthenticationError.V(12)
        )
        LOGIN_COOKIE_REQUIRED = AuthenticationErrorEnum.AuthenticationError.V(13)
        NOT_ADS_USER = AuthenticationErrorEnum.AuthenticationError.V(14)
        OAUTH_TOKEN_INVALID = AuthenticationErrorEnum.AuthenticationError.V(15)
        OAUTH_TOKEN_EXPIRED = AuthenticationErrorEnum.AuthenticationError.V(16)
        OAUTH_TOKEN_DISABLED = AuthenticationErrorEnum.AuthenticationError.V(17)
        OAUTH_TOKEN_REVOKED = AuthenticationErrorEnum.AuthenticationError.V(18)
        OAUTH_TOKEN_HEADER_INVALID = AuthenticationErrorEnum.AuthenticationError.V(19)
        LOGIN_COOKIE_INVALID = AuthenticationErrorEnum.AuthenticationError.V(20)
        USER_ID_INVALID = AuthenticationErrorEnum.AuthenticationError.V(22)
        TWO_STEP_VERIFICATION_NOT_ENROLLED = (
            AuthenticationErrorEnum.AuthenticationError.V(23)
        )
        ADVANCED_PROTECTION_NOT_ENROLLED = (
            AuthenticationErrorEnum.AuthenticationError.V(24)
        )
    class AuthenticationError(metaclass=_AuthenticationError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AuthenticationErrorEnum.AuthenticationError.V(0)
    UNKNOWN = AuthenticationErrorEnum.AuthenticationError.V(1)
    AUTHENTICATION_ERROR = AuthenticationErrorEnum.AuthenticationError.V(2)
    CLIENT_CUSTOMER_ID_INVALID = AuthenticationErrorEnum.AuthenticationError.V(5)
    CUSTOMER_NOT_FOUND = AuthenticationErrorEnum.AuthenticationError.V(8)
    GOOGLE_ACCOUNT_DELETED = AuthenticationErrorEnum.AuthenticationError.V(9)
    GOOGLE_ACCOUNT_COOKIE_INVALID = AuthenticationErrorEnum.AuthenticationError.V(10)
    GOOGLE_ACCOUNT_AUTHENTICATION_FAILED = (
        AuthenticationErrorEnum.AuthenticationError.V(25)
    )
    GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH = (
        AuthenticationErrorEnum.AuthenticationError.V(12)
    )
    LOGIN_COOKIE_REQUIRED = AuthenticationErrorEnum.AuthenticationError.V(13)
    NOT_ADS_USER = AuthenticationErrorEnum.AuthenticationError.V(14)
    OAUTH_TOKEN_INVALID = AuthenticationErrorEnum.AuthenticationError.V(15)
    OAUTH_TOKEN_EXPIRED = AuthenticationErrorEnum.AuthenticationError.V(16)
    OAUTH_TOKEN_DISABLED = AuthenticationErrorEnum.AuthenticationError.V(17)
    OAUTH_TOKEN_REVOKED = AuthenticationErrorEnum.AuthenticationError.V(18)
    OAUTH_TOKEN_HEADER_INVALID = AuthenticationErrorEnum.AuthenticationError.V(19)
    LOGIN_COOKIE_INVALID = AuthenticationErrorEnum.AuthenticationError.V(20)
    USER_ID_INVALID = AuthenticationErrorEnum.AuthenticationError.V(22)
    TWO_STEP_VERIFICATION_NOT_ENROLLED = AuthenticationErrorEnum.AuthenticationError.V(
        23
    )
    ADVANCED_PROTECTION_NOT_ENROLLED = AuthenticationErrorEnum.AuthenticationError.V(24)
    def __init__(
        self,
    ) -> None: ...

global___AuthenticationErrorEnum = AuthenticationErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdGroupType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdGroupTypeEnum.AdGroupType.V(0)
        UNKNOWN = AdGroupTypeEnum.AdGroupType.V(1)
        SEARCH_STANDARD = AdGroupTypeEnum.AdGroupType.V(2)
        DISPLAY_STANDARD = AdGroupTypeEnum.AdGroupType.V(3)
        SHOPPING_PRODUCT_ADS = AdGroupTypeEnum.AdGroupType.V(4)
        HOTEL_ADS = AdGroupTypeEnum.AdGroupType.V(6)
        SHOPPING_SMART_ADS = AdGroupTypeEnum.AdGroupType.V(7)
        VIDEO_BUMPER = AdGroupTypeEnum.AdGroupType.V(8)
        VIDEO_TRUE_VIEW_IN_STREAM = AdGroupTypeEnum.AdGroupType.V(9)
        VIDEO_TRUE_VIEW_IN_DISPLAY = AdGroupTypeEnum.AdGroupType.V(10)
        VIDEO_NON_SKIPPABLE_IN_STREAM = AdGroupTypeEnum.AdGroupType.V(11)
        VIDEO_OUTSTREAM = AdGroupTypeEnum.AdGroupType.V(12)
        SEARCH_DYNAMIC_ADS = AdGroupTypeEnum.AdGroupType.V(13)
        SHOPPING_COMPARISON_LISTING_ADS = AdGroupTypeEnum.AdGroupType.V(14)
        PROMOTED_HOTEL_ADS = AdGroupTypeEnum.AdGroupType.V(15)
        VIDEO_RESPONSIVE = AdGroupTypeEnum.AdGroupType.V(16)
    class AdGroupType(metaclass=_AdGroupType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupTypeEnum.AdGroupType.V(0)
    UNKNOWN = AdGroupTypeEnum.AdGroupType.V(1)
    SEARCH_STANDARD = AdGroupTypeEnum.AdGroupType.V(2)
    DISPLAY_STANDARD = AdGroupTypeEnum.AdGroupType.V(3)
    SHOPPING_PRODUCT_ADS = AdGroupTypeEnum.AdGroupType.V(4)
    HOTEL_ADS = AdGroupTypeEnum.AdGroupType.V(6)
    SHOPPING_SMART_ADS = AdGroupTypeEnum.AdGroupType.V(7)
    VIDEO_BUMPER = AdGroupTypeEnum.AdGroupType.V(8)
    VIDEO_TRUE_VIEW_IN_STREAM = AdGroupTypeEnum.AdGroupType.V(9)
    VIDEO_TRUE_VIEW_IN_DISPLAY = AdGroupTypeEnum.AdGroupType.V(10)
    VIDEO_NON_SKIPPABLE_IN_STREAM = AdGroupTypeEnum.AdGroupType.V(11)
    VIDEO_OUTSTREAM = AdGroupTypeEnum.AdGroupType.V(12)
    SEARCH_DYNAMIC_ADS = AdGroupTypeEnum.AdGroupType.V(13)
    SHOPPING_COMPARISON_LISTING_ADS = AdGroupTypeEnum.AdGroupType.V(14)
    PROMOTED_HOTEL_ADS = AdGroupTypeEnum.AdGroupType.V(15)
    VIDEO_RESPONSIVE = AdGroupTypeEnum.AdGroupType.V(16)
    def __init__(
        self,
    ) -> None: ...

global___AdGroupTypeEnum = AdGroupTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LegacyAppInstallAdAppStoreEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LegacyAppInstallAdAppStore(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            LegacyAppInstallAdAppStore.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(0)
        UNKNOWN = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(1)
        APPLE_APP_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(2)
        GOOGLE_PLAY = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(3)
        WINDOWS_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(4)
        WINDOWS_PHONE_STORE = (
            LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(5)
        )
        CN_APP_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(6)
    class LegacyAppInstallAdAppStore(metaclass=_LegacyAppInstallAdAppStore):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(0)
    UNKNOWN = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(1)
    APPLE_APP_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(2)
    GOOGLE_PLAY = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(3)
    WINDOWS_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(4)
    WINDOWS_PHONE_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(5)
    CN_APP_STORE = LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V(6)
    def __init__(
        self,
    ) -> None: ...

global___LegacyAppInstallAdAppStoreEnum = LegacyAppInstallAdAppStoreEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QualityScoreBucketEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _QualityScoreBucket(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            QualityScoreBucket.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = QualityScoreBucketEnum.QualityScoreBucket.V(0)
        UNKNOWN = QualityScoreBucketEnum.QualityScoreBucket.V(1)
        BELOW_AVERAGE = QualityScoreBucketEnum.QualityScoreBucket.V(2)
        AVERAGE = QualityScoreBucketEnum.QualityScoreBucket.V(3)
        ABOVE_AVERAGE = QualityScoreBucketEnum.QualityScoreBucket.V(4)
    class QualityScoreBucket(metaclass=_QualityScoreBucket):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = QualityScoreBucketEnum.QualityScoreBucket.V(0)
    UNKNOWN = QualityScoreBucketEnum.QualityScoreBucket.V(1)
    BELOW_AVERAGE = QualityScoreBucketEnum.QualityScoreBucket.V(2)
    AVERAGE = QualityScoreBucketEnum.QualityScoreBucket.V(3)
    ABOVE_AVERAGE = QualityScoreBucketEnum.QualityScoreBucket.V(4)
    def __init__(
        self,
    ) -> None: ...

global___QualityScoreBucketEnum = QualityScoreBucketEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PricePlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _PricePlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PricePlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = PricePlaceholderFieldEnum.PricePlaceholderField.V(0)
        UNKNOWN = PricePlaceholderFieldEnum.PricePlaceholderField.V(1)
        TYPE = PricePlaceholderFieldEnum.PricePlaceholderField.V(2)
        PRICE_QUALIFIER = PricePlaceholderFieldEnum.PricePlaceholderField.V(3)
        TRACKING_TEMPLATE = PricePlaceholderFieldEnum.PricePlaceholderField.V(4)
        LANGUAGE = PricePlaceholderFieldEnum.PricePlaceholderField.V(5)
        FINAL_URL_SUFFIX = PricePlaceholderFieldEnum.PricePlaceholderField.V(6)
        ITEM_1_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(100)
        ITEM_1_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(101)
        ITEM_1_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(102)
        ITEM_1_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(103)
        ITEM_1_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(104)
        ITEM_1_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            105
        )
        ITEM_2_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(200)
        ITEM_2_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(201)
        ITEM_2_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(202)
        ITEM_2_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(203)
        ITEM_2_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(204)
        ITEM_2_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            205
        )
        ITEM_3_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(300)
        ITEM_3_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(301)
        ITEM_3_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(302)
        ITEM_3_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(303)
        ITEM_3_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(304)
        ITEM_3_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            305
        )
        ITEM_4_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(400)
        ITEM_4_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(401)
        ITEM_4_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(402)
        ITEM_4_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(403)
        ITEM_4_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(404)
        ITEM_4_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            405
        )
        ITEM_5_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(500)
        ITEM_5_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(501)
        ITEM_5_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(502)
        ITEM_5_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(503)
        ITEM_5_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(504)
        ITEM_5_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            505
        )
        ITEM_6_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(600)
        ITEM_6_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(601)
        ITEM_6_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(602)
        ITEM_6_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(603)
        ITEM_6_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(604)
        ITEM_6_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            605
        )
        ITEM_7_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(700)
        ITEM_7_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(701)
        ITEM_7_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(702)
        ITEM_7_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(703)
        ITEM_7_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(704)
        ITEM_7_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            705
        )
        ITEM_8_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(800)
        ITEM_8_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(801)
        ITEM_8_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(802)
        ITEM_8_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(803)
        ITEM_8_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(804)
        ITEM_8_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(
            805
        )
    class PricePlaceholderField(metaclass=_PricePlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = PricePlaceholderFieldEnum.PricePlaceholderField.V(0)
    UNKNOWN = PricePlaceholderFieldEnum.PricePlaceholderField.V(1)
    TYPE = PricePlaceholderFieldEnum.PricePlaceholderField.V(2)
    PRICE_QUALIFIER = PricePlaceholderFieldEnum.PricePlaceholderField.V(3)
    TRACKING_TEMPLATE = PricePlaceholderFieldEnum.PricePlaceholderField.V(4)
    LANGUAGE = PricePlaceholderFieldEnum.PricePlaceholderField.V(5)
    FINAL_URL_SUFFIX = PricePlaceholderFieldEnum.PricePlaceholderField.V(6)
    ITEM_1_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(100)
    ITEM_1_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(101)
    ITEM_1_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(102)
    ITEM_1_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(103)
    ITEM_1_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(104)
    ITEM_1_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(105)
    ITEM_2_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(200)
    ITEM_2_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(201)
    ITEM_2_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(202)
    ITEM_2_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(203)
    ITEM_2_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(204)
    ITEM_2_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(205)
    ITEM_3_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(300)
    ITEM_3_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(301)
    ITEM_3_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(302)
    ITEM_3_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(303)
    ITEM_3_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(304)
    ITEM_3_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(305)
    ITEM_4_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(400)
    ITEM_4_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(401)
    ITEM_4_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(402)
    ITEM_4_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(403)
    ITEM_4_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(404)
    ITEM_4_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(405)
    ITEM_5_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(500)
    ITEM_5_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(501)
    ITEM_5_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(502)
    ITEM_5_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(503)
    ITEM_5_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(504)
    ITEM_5_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(505)
    ITEM_6_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(600)
    ITEM_6_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(601)
    ITEM_6_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(602)
    ITEM_6_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(603)
    ITEM_6_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(604)
    ITEM_6_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(605)
    ITEM_7_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(700)
    ITEM_7_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(701)
    ITEM_7_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(702)
    ITEM_7_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(703)
    ITEM_7_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(704)
    ITEM_7_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(705)
    ITEM_8_HEADER = PricePlaceholderFieldEnum.PricePlaceholderField.V(800)
    ITEM_8_DESCRIPTION = PricePlaceholderFieldEnum.PricePlaceholderField.V(801)
    ITEM_8_PRICE = PricePlaceholderFieldEnum.PricePlaceholderField.V(802)
    ITEM_8_UNIT = PricePlaceholderFieldEnum.PricePlaceholderField.V(803)
    ITEM_8_FINAL_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(804)
    ITEM_8_FINAL_MOBILE_URLS = PricePlaceholderFieldEnum.PricePlaceholderField.V(805)
    def __init__(
        self,
    ) -> None: ...

global___PricePlaceholderFieldEnum = PricePlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TextLabel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    background_color: typing.Text = ...
    description: typing.Text = ...
    def __init__(
        self,
        *,
        background_color: typing.Text = ...,
        description: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_background_color",
            b"_background_color",
            "_description",
            b"_description",
            "background_color",
            b"background_color",
            "description",
            b"description",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_background_color",
            b"_background_color",
            "_description",
            b"_description",
            "background_color",
            b"background_color",
            "description",
            b"description",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_background_color", b"_background_color"
        ],
    ) -> typing_extensions.Literal["background_color"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...

global___TextLabel = TextLabel
